# Setup in SAP LeanIX
### On this page
  * [Adding a Configuration](https://help.sap.com/docs/leanix/ea/setup-in-sap-leanix#adding-a-configuration)
  * [Configuration Page Overview](https://help.sap.com/docs/leanix/ea/setup-in-sap-leanix#configuration-page-overview)
  * [Credential Configuration](https://help.sap.com/docs/leanix/ea/setup-in-sap-leanix#credential-configuration)
  * [Partial Sync Mode](https://help.sap.com/docs/leanix/ea/setup-in-sap-leanix#partial-sync-mode)
  * [Authentication Options for ServiceNow](https://help.sap.com/docs/leanix/ea/setup-in-sap-leanix#authentication-options-for-servicenow)
  * [Synchronization](https://help.sap.com/docs/leanix/ea/setup-in-sap-leanix#synchronization)
  * [Manual Full Sync](https://help.sap.com/docs/leanix/ea/setup-in-sap-leanix#manual-full-sync)
  * [Scheduled Full Sync](https://help.sap.com/docs/leanix/ea/setup-in-sap-leanix#scheduled-full-sync)


View all
After configuring the SAP LeanIX app in ServiceNow, set up the integration in SAP LeanIX.
This document is in continuation of the [Setup in ServiceNow](https://help.sap.com/docs/leanix/ea/setup-in-servicenow?locale=en-US&state=PRODUCTION&version=CLOUD "Configure the ServiceNow integration on the ServiceNow side.") document. Please ensure the outlined steps there are complete before proceeding with the setup in SAP LeanIX.
